.. _receptoren:

RECEPTOREN
##########

De volgende informatie geldt voor antipsychotica in het algemeen:

Blokkade van dopamine D 2-receptoren in het voorste deel van de hypofyse stimuleert prolactinesecretie en kan leiden tot o.a. gynecomastie, menstruele veranderingen en seksuele dysfunctie [bre, had].

Blokkade van dopamine D 2-receptoren in het voorste deel van de hypothalamus verstoort de temperatuurregulatie, resulterend in hypo- of hyperthermie, afhankelijk van de omgevingstemperatuur [bre, had].

Extrapiramidale symptomen worden veroorzaakt door blokkade van D 2-dopamine receptoren in het nigrostriatum [gol, had]. De kans op extrapiramidale symptomen hangt af van de verhouding tussen nigrostriatale D 2-receptor blokkade en mesolimbische/mesocorticale D 2-receptor blokkade [had]. Een relatief hoge antagonistische affiniteit voor M 1-muscarinerge receptoren en 5-HT 1A- en 5-HT 2A-serotonerge receptoren lijkt de kans op extrapiramidale symptomen te verlagen [bre, had].

Het maligne neurolepticumsyndroom ontstaat door blokkade van dopamine D 2-receptoren in de hypothalamus en het nigrostriatum [bre, had].

Blokkade van alfa 1-adrenerge receptoren kan leiden tot onder andere orthostatische hypotensie, reflextachycardie en miosis [dar, bre, had].

Binding aan H 1-histamine receptoren veroorzaakt depressie van het centrale zenuwstelsel, toename van de eetlust en hypotensie [bre, had].

Blokkade van M 1-muscarinerge receptoren veroorzaakt anticholinerge effecten, zoals agitatie, hallucinaties, delier, tachycardie, mydriasis, wazig zicht, droge huid en slijmvliezen, ileus en urineretentie [bre, had].

Myocardiale depressie en dysritmieën worden mogelijk veroorzaakt door "kinidine-achtige" blokkade van natrium-, kalium- en calcium-ionkanalen [dar].
